This function calculates average treatment effects and heterogeneity effects from an estimated endogenous switching regression model.
treatmentEffect(
Results,
data,
OutcomeDep,
SelectDep,
OutcomeCov,
SelectCov,
treatEffect
)Estimated endogenous switching regression model.
a data frame. Data for running the regression analysis.
character. Dependent variable in the outcome equation.
character. Dependent variable in the Selection model. The variable must be binary (0 or 1).
character vector. Covariates in the outcome equation.
character vector. Covariates in the selection equation.
TRUE/FALSE. Show average treatment effects or expected outcome values.
A data table that reports the average treatment effects or a list of two tables reporting expected outcome values.